/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.social.bookmarks;

import java.util.List;

/**
 * Provides methods to read the available social bookmarks.
 *
 * @author Alejandro Tardín
 */
public interface SocialBookmarksRegistry {

	/**
	 * Retrieves a social bookmark given its type (e.g., {@code facebook}).
	 *
	 * @param  type the social bookmark's key
	 * @return the social bookmark
	 */
	public SocialBookmark getSocialBookmark(String type);

	/**
	 * Retrieves all available social bookmarks.
	 *
	 * @return the social bookmarks
	 */
	public List<SocialBookmark> getSocialBookmarks();

	/**
	 * Retrieves all available social bookmark types. These are the keys that
	 * identify each social bookmark.
	 *
	 * @return the social bookmark types
	 */
	public List<String> getSocialBookmarksTypes();

}